<?php
/**
 * Base exception class for Horde_ActiveSync
 *
 * Copyright 2010-2014 Horde LLC (http://www.horde.org/)
 *
 * @license   http://www.horde.org/licenses/gpl GPLv2
 *            NOTE: According to sec. 8 of the GENERAL PUBLIC LICENSE (GPL),
 *            Version 2, the distribution of the Horde_ActiveSync module in or
 *            to the United States of America is excluded from the scope of this
 *            license.
 * @copyright 2010-2014 Horde LLC (http://www.horde.org)
 * @author    Michael J Rubinsky <mrubinsk@horde.org>
 * @package   ActiveSync
 */
/**
 * Base exception class for Horde_ActiveSync
 *
 * Copyright 2010-2014 Horde LLC (http://www.horde.org/)
 *
 * @license   http://www.horde.org/licenses/gpl GPLv2
 *            NOTE: According to sec. 8 of the GENERAL PUBLIC LICENSE (GPL),
 *            Version 2, the distribution of the Horde_ActiveSync module in or
 *            to the United States of America is excluded from the scope of this
 *            license.
 * @copyright 2010-2014 Horde LLC (http://www.horde.org)
 * @author    Michael J Rubinsky <mrubinsk@horde.org>
 * @package   ActiveSync
 */
class Horde_ActiveSync_Exception extends Horde_Exception_Wrapped
{
    /** Error codes **/

    // Defauld, unspecified.
    const UNSPECIFIED = 0;

    // Unsupported action was attempted.
    const UNSUPPORTED = 3;
}